==> jc-1.4.0.tar.gz: gnu/java/security/provider/DSAParameterGenerator.h <==
// public class gnu.java.security.provider.DSAParameterGenerator

// class file dependencies
// @dep_class 55d53ae0ac5cc6a gnu_java_security_provider_DSAParameterGenerator
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d641d91cd6167b5d java_security_AlgorithmParameterGeneratorSpi

// header file dependencies
// @dep_header java_security_AlgorithmParameterGeneratorSpi

#include "java/security/AlgorithmParameterGeneratorSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAParameterGenerator_H_
#define _JC_gnu_java_security_provider_DSAParameterGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs	_jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs	_jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$refs	_jc_gnu_java_security_provider_DSAParameterGenerator$refs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs	_jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$object	_jc_gnu_java_security_provider_DSAParameterGenerator$object;

typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vmethods	_jc_gnu_java_security_provider_DSAParameterGenerator$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtable	_jc_gnu_java_security_provider_DSAParameterGenerator$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtype	_jc_gnu_java_security_provider_DSAParameterGenerator$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *);

// Virtual methods
extern struct _jc_java_security_AlgorithmParameters$object *_jc_gnu_java_security_provider_DSAParameterGenerator$method$engineGenerateParameters$c500aa80c3b5d11e(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *);
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineGenerateParameters$c500aa80c3b5d11e;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineInit$5af33bc7d4d69573;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vmethods {
	struct _jc_java_security_AlgorithmParameters$object	*(*engineGenerateParameters$c500aa80c3b5d11e)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *);
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *);
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	java_security_AlgorithmParameterGeneratorSpi;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vmethods	gnu_java_security_provider_DSAParameterGenerator;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs {
	struct _jc_java_security_SecureRandom$object	*random;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$refs {
    _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs	gnu_java_security_provider_DSAParameterGenerator;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs	gnu_java_security_provider_DSAParameterGenerator;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAParameterGenerator$object {
	_jc_gnu_java_security_provider_DSAParameterGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAParameterGenerator$vtype _jc_gnu_java_security_provider_DSAParameterGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAParameterGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAParameterGenerator$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAParameterGenerator_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/DSAParameterGenerator.h <==
// public class gnu.java.security.provider.DSAParameterGenerator

// class file dependencies
// @dep_class 55d53ae0ac5cc6a gnu_java_security_provider_DSAParameterGenerator
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d641d91cd6167b5d java_security_AlgorithmParameterGeneratorSpi

// header file dependencies
// @dep_header java_security_AlgorithmParameterGeneratorSpi

#include "java/security/AlgorithmParameterGeneratorSpi.h"

#ifndef _JC_gnu_java_security_provider_DSAParameterGenerator_H_
#define _JC_gnu_java_security_provider_DSAParameterGenerator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_AlgorithmParameters$object;
struct _jc_java_security_SecureRandom$object;
struct _jc_java_security_spec_AlgorithmParameterSpec$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs	_jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs	_jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$refs	_jc_gnu_java_security_provider_DSAParameterGenerator$refs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs	_jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs;
typedef struct _jc_gnu_java_security_provider_DSAParameterGenerator$object	_jc_gnu_java_security_provider_DSAParameterGenerator$object;

typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vmethods	_jc_gnu_java_security_provider_DSAParameterGenerator$vmethods;
typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtable	_jc_gnu_java_security_provider_DSAParameterGenerator$vtable;
typedef const struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtype	_jc_gnu_java_security_provider_DSAParameterGenerator$vtype;

// Constructors
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_AlgorithmParameters$object *_jc_gnu_java_security_provider_DSAParameterGenerator$method$engineGenerateParameters$c500aa80c3b5d11e(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$engineInit$ce17ad6b3fc98d82(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$engineInit$5af33bc7d4d69573(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DSAParameterGenerator$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineGenerateParameters$c500aa80c3b5d11e;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineInit$ce17ad6b3fc98d82;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$engineInit$5af33bc7d4d69573;
extern _jc_method _jc_gnu_java_security_provider_DSAParameterGenerator$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vmethods {
	struct _jc_java_security_AlgorithmParameters$object	*(*engineGenerateParameters$c500aa80c3b5d11e)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *) _JC_JCNI_ATTR;
	void	(*engineInit$ce17ad6b3fc98d82)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, jint, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*engineInit$5af33bc7d4d69573)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *, struct _jc_object *, struct _jc_java_security_SecureRandom$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_security_provider_DSAParameterGenerator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_AlgorithmParameterGeneratorSpi$vmethods	java_security_AlgorithmParameterGeneratorSpi;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vmethods	gnu_java_security_provider_DSAParameterGenerator;
};

// Vtype
struct _jc_gnu_java_security_provider_DSAParameterGenerator$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs {
	struct _jc_java_security_SecureRandom$object	*random;
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$refs {
    _jc_gnu_java_security_provider_DSAParameterGenerator$sub_refs	gnu_java_security_provider_DSAParameterGenerator;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_refs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs {
	jint	size;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_AlgorithmParameterGeneratorSpi$sub_nonrefs	java_security_AlgorithmParameterGeneratorSpi;
    _jc_gnu_java_security_provider_DSAParameterGenerator$sub_nonrefs	gnu_java_security_provider_DSAParameterGenerator;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DSAParameterGenerator$object {
	_jc_gnu_java_security_provider_DSAParameterGenerator$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DSAParameterGenerator$vtype	*vtype;
	_jc_gnu_java_security_provider_DSAParameterGenerator$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DSAParameterGenerator$vtype _jc_gnu_java_security_provider_DSAParameterGenerator$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DSAParameterGenerator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DSAParameterGenerator$class_object;

#endif	/* _JC_gnu_java_security_provider_DSAParameterGenerator_H_ */
